@@ -1,9 +1,13 @@
+# Copyrights 2001-2007 by Mark Overmeer.
+#  For other contributors see ChangeLog.
+# See the manual pages for details on the licensing terms.
+# Pod stripped from pm file by OODoc 1.03.
 use strict;
 use warnings;
 
 package Mail::Message::Body;
 use vars '$VERSION';
-$VERSION = '2.068';
+$VERSION = '2.078';
 use base 'Mail::Reporter';
 
 use Mail::Message::Field;
@@ -11,7 +15,7 @@ use Mail::Message::Body::Lines;
 use Mail::Message::Body::File;
 
 use Carp;
-use Scalar::Util     'weaken';
+use Scalar::Util     qw/weaken refaddr/;
 use File::Basename   'basename';
 
 use MIME::Types;
@@ -22,8 +26,8 @@ my $mime_plain = $mime_types->type('text/plain');
 use overload bool  => sub {1}   # $body->print if $body
            , '""'  => 'string_unless_carp'
            , '@{}' => 'lines'
-           , '=='  => sub {$_[0]->{MMB_seqnr}==$_[1]->{MMB_seqnr}}
-           , '!='  => sub {$_[0]->{MMB_seqnr}!=$_[1]->{MMB_seqnr}};
+           , '=='  => sub {ref $_[1] && refaddr $_[0] == refaddr $_[1]}
+           , '!='  => sub {ref $_[1] && refaddr $_[0] != refaddr $_[1]};
 
 #------------------------------------------
 
