@@ -1,18 +1,21 @@
+# Copyrights 2001-2007 by Mark Overmeer.
+#  For other contributors see ChangeLog.
+# See the manual pages for details on the licensing terms.
+# Pod stripped from pm file by OODoc 1.03.
 
 use strict;
 
 package Mail::Message;
 use vars '$VERSION';
-$VERSION = '2.055';
+$VERSION = '2.078';
 
 use Mail::Message::Head::Complete;
 use Mail::Message::Body::Lines;
 use Mail::Message::Body::Multipart;
 
 use Mail::Address;
-use Carp;
-use Scalar::Util 'blessed';
-use List::Util   'first';
+use Scalar::Util    'blessed';
+use List::Util      'first';
 use Mail::Box::FastScalar;
 
 
@@ -26,12 +29,15 @@ sub rebuild(@)
     # Collect the rules to be run
 
     my @rules   = $args{rules} ? @{$args{rules}} : @default_rules;
-    unshift @rules, @{$args{extraRules}} if $args{extraRules};
+    unshift @rules, @{$args{extra_rules}} if $args{extra_rules};
+    unshift @rules, @{$args{extraRules}}  if $args{extraRules}; #old name
 
     foreach my $rule (@rules)
     {   next if ref $rule;
-        croak "ERROR: no rebuild rule '$rule' defined.\n"
-           unless $self->can($rule);
+        unless($self->can($rule))
+        {   $self->log(ERROR => "No rebuild rule '$rule' defined.\n");
+            return 1;
+        }
     }
 
     # Start off with the message
@@ -82,7 +88,7 @@ sub flattenEmptyMultiparts($@)
                  || Mail::Message::Body::Lines->new(data => '');
     my $epilogue = $body->epilogue;
     my $newbody  = $preamble->concatenate($preamble, <<NO_PARTS, $epilogue);
-
+  * PLEASE NOTE:
   * This multipart did not contain any parts (anymore)
   * and was therefore flattened.
 
@@ -111,13 +117,13 @@ sub descendMultiparts($@)
 
     foreach my $part ($body->parts)
     {   my $new = $self->recursiveRebuildPart($part, %args);
-
         if(!defined $new)  { $changed++ }
 	elsif($new==$part) { push @newparts, $part }
 	else               { push @newparts, $new; $changed++ }
     }
 
-    return $part unless $changed;
+    $changed
+       or return $part;
 
     my $newbody = ref($body)->new
      ( based_on  => $body
@@ -151,7 +157,11 @@ sub descendNested($@)
       , nested   => $newnested
       );
 
-   my $rebuild    = ref($part)->new(head => $part->head->clone);
+   my $rebuild    = ref($part)->new
+    ( head       => $part->head->clone
+    , container => undef
+    );
+
    $rebuild->body($newbody);
    $rebuild;
 }
@@ -258,24 +268,21 @@ sub recursiveRebuildPart($@)
 {   my ($self, $part, %args) = @_;
 
   RULES:
-    for(1)
-    {
-        foreach my $rule ( @{$args{rules}} )
-        {
-            my $rebuild
-               = ref $rule ? $rule->($self, $part, %args)
-               :             $self->$rule($part, %args);
+    foreach my $rule ( @{$args{rules}} )
+    {   my $rebuild
+           = ref $rule ? $rule->($self, $part, %args)
+           :             $self->$rule($part, %args);
 
-            return undef unless defined $rebuild;
+        defined $rebuild
+            or return undef;
 
-            if($part != $rebuild)
-            {   $part = $rebuild;
-                redo RULES;
-            }
-	}
+        if($part != $rebuild)
+        {   $part = $rebuild;
+            redo RULES;
+        }
     }
 
-   $part;
+    $part;
 }
 
 #------------------------------------------
